@@ -4,7 +4,7 @@ from typing import Dict
 
 import sys
 import argparse
-from collections import OrderedDict, defaultdict
+from collections import defaultdict
 from operator import itemgetter
 
 from dark.aligners import edlibAlign, mafft, needle
@@ -282,9 +282,9 @@ def collectData(reads1, reads2, square, matchAmbiguous, pairwiseAlign,
     """
     Get pairwise matching statistics for two sets of reads.
 
-    @param reads1: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads1: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the rows of the table.
-    @param reads2: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads2: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the columns of the table.
     @param square: If C{True} we are making a square table of a set of
         sequences against themselves (in which case we show nothing on the
@@ -340,8 +340,8 @@ def collectData(reads1, reads2, square, matchAmbiguous, pairwiseAlign,
 
 def computeIdentity(read1, read2, stats, matchAmbiguous, digits):
     """
-    Compute nucleotide identity for two reads (as a fraction of the number
-    of relevant nucleotides in the first read).
+    Compute nucleotide identity for two reads (as a fraction of the lowest
+    number of relevant nucleotides in either read).
 
     @param read1: A C{Read} instance.
     @param read2: A C{Read} instance.
@@ -369,13 +369,11 @@ def computeIdentity(read1, read2, stats, matchAmbiguous, digits):
     # matched by read2 and this can pull the overall identity higher than
     # the strict identity.
 
-    gapCount = len(stats['read1']['gapOffsets'])
-    noCoverageCount = (stats['match']['noCoverageCount'] +
-                       stats['match']['noCoverageNoCoverageCount'])
-    length = stats['read1']['length']
+    match = stats['match']
+    denominator = min(stats['read1']['length'], stats['read2']['length']) - (
+        match['gapGapMismatchCount'] +
+        match['noCoverageCount'] + match['noCoverageNoCoverageCount'])
     numerator = stats['match']['identicalMatchCount']
-    denominator = length - gapCount - noCoverageCount
-
     if matchAmbiguous:
         numerator += stats['match']['ambiguousMatchCount']
 
@@ -393,9 +391,9 @@ def textTable(tableData, reads1, reads2, readNumbers, square, matchAmbiguous,
 
     @param tableData: A C{defaultdict(dict)} keyed by read ids, whose values
         are the dictionaries returned by compareDNAReads.
-    @param reads1: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads1: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the rows of the table.
-    @param reads2: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads2: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the columns of the table.
     @param readNumbers: A C{dict} mapping read ids to row numbers (only
         used if square is C{True} (in which case reads1 is the same as reads2).
@@ -461,9 +459,9 @@ def htmlTable(tableData, reads1, reads2, square, readNumbers, matchAmbiguous,
 
     @param tableData: A C{defaultdict(dict)} keyed by read ids, whose values
         are the dictionaries returned by compareDNAReads.
-    @param reads1: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads1: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the rows of the table.
-    @param reads2: An C{OrderedDict} of C{str} read ids whose values are
+    @param reads2: An C{dict} of C{str} read ids whose values are
         C{Read} instances. These will be the columns of the table.
     @param readNumbers: A C{dict} mapping read ids to row numbers (only
         used if square is C{True} (in which case reads1 is the same as reads2).
@@ -786,6 +784,10 @@ if __name__ == '__main__':
               'input file is given, resulting in a square all-against-all '
               'identity table).'))
 
+    parser.add_argument(
+        '--sort', action='store_true',
+        help='Sort the input sequences by id.')
+
     parser.add_argument(
         '--aligner', default='edlib', choices=('edlib', 'mafft', 'needle'),
         help='The alignment algorithm to use.')
@@ -821,9 +823,10 @@ if __name__ == '__main__':
         args, parseFASTAFilteringCommandLineOptions(
             args, parseFASTACommandLineOptions(args)))
 
-    # Collect the reads into a dict, keeping the insertion order.
-    reads1 = OrderedDict()
-    for read in reads:
+    # Collect the reads into a dict, keeping the insertion order, unless we
+    # are told to sort.
+    reads1 = {}
+    for read in (sorted(reads) if args.sort else reads):
         reads1[read.id] = read
 
     if args.fastaFile2:
@@ -833,7 +836,7 @@ if __name__ == '__main__':
             sys.exit(1)
 
         square = False
-        reads2 = OrderedDict()
+        reads2 = {}
         # The next line is a total hack, to trick parseFASTACommandLineOptions
         # into reading a second FASTA file.
         args.fastaFile = args.fastaFile2
@@ -861,7 +864,8 @@ if __name__ == '__main__':
                 colors=colors, concise=args.concise,
                 showLengths=args.showLengths, showGaps=args.showGaps,
                 showNs=args.showNs, footer=args.footer, div=args.div,
-                gapChars=args.gapChars, noCoverageChars=args.noCoverageChars,
+                gapChars=args.gapChars, showNoCoverage=args.showNoCoverage,
+                noCoverageChars=args.noCoverageChars,
                 numberedColumns=args.numberedColumns, upperOnly=args.upperOnly,
                 digits=args.digits, addZeroes=args.addZeroes,
                 highlightBest=args.highlightBest))
