@@ -2,13 +2,11 @@ import sys
 from collections import defaultdict
 from pysam import CINS, CDEL, CSOFT_CLIP
 
-from dark.cigar import (
-    cigarTuplesToOperations, softClippedOffset, insertionOffset)
+from dark.cigar import cigarTuplesToOperations, softClippedOffset, insertionOffset
 from dark.dna import Bases
 from dark.progress import maybeProgressBar
 from dark.reads import DNARead
-from dark.sam import (
-    samfile, getReferenceInfo, UnspecifiedReference, CONSUMES_REFERENCE)
+from dark.sam import samfile, getReferenceInfo, UnspecifiedReference, CONSUMES_REFERENCE
 from dark.utils import pct
 
 DEBUG = False
@@ -19,7 +17,7 @@ def debug(*msg):
 
 
 class ConsensusError(Exception):
-    'A consensus-making error.'
+    "A consensus-making error."
 
 
 class Insertion:
@@ -29,6 +27,7 @@ class Insertion:
 
     @param insertionOffset: The C{int} offset of the insertion.
     """
+
     def __init__(self, insertionOffset):
         self.insertionOffset = insertionOffset
         self.anchorOffsets = []
@@ -38,10 +37,9 @@ class Insertion:
         result = []
 
         for anchorOffset, bases in zip(self.anchorOffsets, self.bases):
-            result.append(f'  {anchorOffset}: {bases}')
+            result.append(f"  {anchorOffset}: {bases}")
 
-        return (f'<Insertion at {self.insertionOffset}:\n' +
-                '\n'.join(result) + '>')
+        return f"<Insertion at {self.insertionOffset}:\n" + "\n".join(result) + ">"
 
     __repr__ = __str__
 
@@ -90,11 +88,14 @@ class Insertion:
         maxExtra = 0
         for anchorOffset, bases in zip(self.anchorOffsets, self.bases):
             if anchorOffset is not None:
-                extra = (self.insertionOffset + nInsertions - anchorOffset -
-                         len(bases) - 1)
+                extra = (
+                    self.insertionOffset + nInsertions - anchorOffset - len(bases) - 1
+                )
                 if DEBUG:
-                    debug(f'{extra} = {self.insertionOffset} + '
-                          f'{nInsertions} - {anchorOffset} - {len(bases)} - 1')
+                    debug(
+                        f"{extra} = {self.insertionOffset} + "
+                        f"{nInsertions} - {anchorOffset} - {len(bases)} - 1"
+                    )
                 if extra > maxExtra:
                     maxExtra = extra
 
@@ -107,22 +108,31 @@ class Insertion:
             insertion.append(Bases())
 
         for anchorOffset, bases in zip(self.anchorOffsets, self.bases):
-            startOffset = (
-                nInsertions - len(bases) if anchorOffset is None else 0)
+            startOffset = nInsertions - len(bases) if anchorOffset is None else 0
             for offset, (base, quality) in enumerate(bases):
                 insertion[startOffset + offset].append(base, quality)
 
         if DEBUG:
-            debug('insertion')
+            debug("insertion")
             for i in insertion:
-                debug('\t', i)
+                debug("\t", i)
 
         return insertion
 
 
-def basesToConsensus(offsetBases, otherBases, originalOffsets, reference,
-                     referenceLength, threshold, minCoverage, lowCoverage,
-                     noCoverage, deletionSymbol, progress):
+def basesToConsensus(
+    offsetBases,
+    otherBases,
+    originalOffsets,
+    reference,
+    referenceLength,
+    threshold,
+    minCoverage,
+    lowCoverage,
+    noCoverage,
+    deletionSymbol,
+    progress,
+):
     """
     Convert a C{dict} of C{Bases} into a consensus.
 
@@ -152,49 +162,59 @@ def basesToConsensus(offsetBases, otherBases, originalOffsets, reference,
     @return: a C{str} consensus sequence.
     """
     if DEBUG:
-        debug('In basesToConsensus: offsetBases:')
+        debug("In basesToConsensus: offsetBases:")
         for offset in offsetBases:
-            debug(f'  {offset}: {offsetBases[offset]}')
-        debug('In basesToConsensus: otherBases:')
+            debug(f"  {offset}: {offsetBases[offset]}")
+        debug("In basesToConsensus: otherBases:")
         for offset in otherBases:
-            debug(f'  {offset}: {otherBases[offset]}')
+            debug(f"  {offset}: {otherBases[offset]}")
 
     result = []
     allOffsets = set(offsetBases) | set(otherBases) | {0}
     minOffset = min(allOffsets)
     maxOffset = max(allOffsets)
 
-    noCoverageStr = (reference.sequence if noCoverage == 'reference' else
-                     noCoverage * referenceLength)
-    lowCoverageStr = (reference.sequence if lowCoverage == 'reference' else
-                      lowCoverage * referenceLength)
+    noCoverageStr = (
+        reference.sequence
+        if noCoverage == "reference"
+        else noCoverage * referenceLength
+    )
+    lowCoverageStr = (
+        reference.sequence
+        if lowCoverage == "reference"
+        else lowCoverage * referenceLength
+    )
 
-    with maybeProgressBar(
-            progress, maxOffset - minOffset + 1, 'Consensus: ') as bar:
-        for barCount, offset in enumerate(
-                range(minOffset, maxOffset + 1), start=1):
+    with maybeProgressBar(progress, maxOffset - minOffset + 1, "Consensus: ") as bar:
+        for barCount, offset in enumerate(range(minOffset, maxOffset + 1), start=1):
             try:
                 originalOffset = originalOffsets[offset]
                 lowCoverageBase = lowCoverageStr[originalOffset]
                 noCoverageBase = noCoverageStr[originalOffset]
             except (IndexError, KeyError):
                 # TODO: Check this out. Add a variable to set this or... ?
-                lowCoverageBase = noCoverageBase = '?'
+                lowCoverageBase = noCoverageBase = "?"
 
             if offset in otherBases and (
-                    offset not in offsetBases or not offsetBases[offset]):
-                result.append(deletionSymbol if otherBases[offset] is None
-                              else otherBases[offset])
+                offset not in offsetBases or not offsetBases[offset]
+            ):
+                result.append(
+                    deletionSymbol if otherBases[offset] is None else otherBases[offset]
+                )
             else:
-                assert offset in offsetBases, (
-                    f'Offset {offset} not found in offsetBases or otherBases.')
+                assert (
+                    offset in offsetBases
+                ), f"Offset {offset} not found in offsetBases or otherBases."
                 bases = offsetBases[offset]
-                result.append(bases.consensus(
-                    threshold, minCoverage, lowCoverageBase, noCoverageBase))
+                result.append(
+                    bases.consensus(
+                        threshold, minCoverage, lowCoverageBase, noCoverageBase
+                    )
+                )
 
             bar.update(barCount)
 
-    return ''.join(result)
+    return "".join(result)
 
 
 def getConsensusId(bamId, idLambda):
@@ -209,7 +229,7 @@ def getConsensusId(bamId, idLambda):
     @return: A C{str} sequence id for the consensus.
     """
     if idLambda is None:
-        consensusId = f'{bamId}-consensus'
+        consensusId = f"{bamId}-consensus"
     else:
         idLambda = eval(idLambda)
         consensusId = idLambda(bamId)
@@ -218,13 +238,26 @@ def getConsensusId(bamId, idLambda):
 
 
 def consensusFromBAM(
-        bamFilename, bamId=None, referenceFasta=None, fastaId=None,
-        consensusId=None, idLambda=None, threshold=0.8, minCoverage=1,
-        lowCoverage='reference', noCoverage='reference',
-        deletionSymbol='-', deletionThreshold=0.5, ignoreQuality=False,
-        insertionCountThreshold=5, strategy='fetch',
-        includeSoftClipped=False, compareWithPileupFile=None, progress=False,
-        quiet=False):
+    bamFilename,
+    bamId=None,
+    referenceFasta=None,
+    fastaId=None,
+    consensusId=None,
+    idLambda=None,
+    threshold=0.8,
+    minCoverage=1,
+    lowCoverage="reference",
+    noCoverage="reference",
+    deletionSymbol="-",
+    deletionThreshold=0.5,
+    ignoreQuality=False,
+    insertionCountThreshold=5,
+    strategy="fetch",
+    includeSoftClipped=False,
+    compareWithPileupFile=None,
+    progress=False,
+    quiet=False,
+):
     """
     Build a consensus sequence from a BAM file.
 
@@ -294,59 +327,86 @@ def consensusFromBAM(
     @return: A C{Read} instance with the consensus sequence.
     """
     if referenceFasta is None:
-        if lowCoverage == 'reference':
-            raise UnspecifiedReference('lowCoverage is "reference" but no '
-                                       'reference FASTA file was given.')
+        if lowCoverage == "reference":
+            raise UnspecifiedReference(
+                'lowCoverage is "reference" but no ' "reference FASTA file was given."
+            )
 
-        if noCoverage == 'reference':
-            raise UnspecifiedReference('noCoverage is "reference" but no '
-                                       'reference FASTA file was given.')
+        if noCoverage == "reference":
+            raise UnspecifiedReference(
+                'noCoverage is "reference" but no ' "reference FASTA file was given."
+            )
 
     with samfile(bamFilename) as bam:
 
         bamId, reference, referenceLength = getReferenceInfo(
-            bam, bamFilename, bamId, referenceFasta, fastaId, quiet)
+            bam, bamFilename, bamId, referenceFasta, fastaId, quiet
+        )
 
         if consensusId is None:
             consensusId = getConsensusId(bamId, idLambda)
 
         correspondences, deletions, insertions = getPairs(
-            bam, bamId, referenceLength, ignoreQuality,
-            includeSoftClipped, progress)
+            bam, bamId, referenceLength, ignoreQuality, includeSoftClipped, progress
+        )
 
         conflicts = set(deletions) & set(insertions)
         if conflicts and DEBUG:
-            debug('CONFLICTING OFFSETS:',
-                  ', '.join(sorted(map(str, conflicts))))
+            debug("CONFLICTING OFFSETS:", ", ".join(sorted(map(str, conflicts))))
 
-        if strategy == 'fetch':
-            correspondences, consensusBases, otherBases, originalOffsets = (
-                fetchConsensus(bam, correspondences, deletions, insertions,
-                               reference, referenceLength, noCoverage,
-                               deletionThreshold, ignoreQuality,
-                               insertionCountThreshold, includeSoftClipped,
-                               progress))
+        if strategy == "fetch":
+            (
+                correspondences,
+                consensusBases,
+                otherBases,
+                originalOffsets,
+            ) = fetchConsensus(
+                bam,
+                correspondences,
+                deletions,
+                insertions,
+                reference,
+                referenceLength,
+                noCoverage,
+                deletionThreshold,
+                ignoreQuality,
+                insertionCountThreshold,
+                includeSoftClipped,
+                progress,
+            )
         else:
-            raise ConsensusError(f'Unknown consensus strategy {strategy!r}.')
+            raise ConsensusError(f"Unknown consensus strategy {strategy!r}.")
 
         if compareWithPileupFile:
-            with open(compareWithPileupFile, 'w') as fp:
+            with open(compareWithPileupFile, "w") as fp:
                 compareCorrespondences(
-                    fp, correspondences,
-                    pileupCorrespondences(bam, bamId, referenceLength,
-                                          includeSoftClipped, progress),
-                    threshold, minCoverage)
+                    fp,
+                    correspondences,
+                    pileupCorrespondences(
+                        bam, bamId, referenceLength, includeSoftClipped, progress
+                    ),
+                    threshold,
+                    minCoverage,
+                )
 
     consensus = basesToConsensus(
-        consensusBases, otherBases, originalOffsets, reference,
-        referenceLength, threshold, minCoverage, lowCoverage, noCoverage,
-        deletionSymbol, progress)
+        consensusBases,
+        otherBases,
+        originalOffsets,
+        reference,
+        referenceLength,
+        threshold,
+        minCoverage,
+        lowCoverage,
+        noCoverage,
+        deletionSymbol,
+        progress,
+    )
 
     return DNARead(consensusId, consensus)
 
 
-def getPairs(bam, bamId, referenceLength, ignoreQuality,
-             includeSoftClipped, progress):
+def getPairs(bam, bamId, referenceLength, ignoreQuality, includeSoftClipped, progress):
     """Compute a majority consensus using pysam's fetch function.
 
     @param bam: An open BAM file.
@@ -371,43 +431,59 @@ def getPairs(bam, bamId, referenceLength, ignoreQuality,
     insertions = {}
     nReads = bam.count(contig=bamId)
 
-    with maybeProgressBar(progress, nReads, 'Reads    : ') as bar:
-        for readCount, read in enumerate(bam.fetch(contig=bamId),
-                                         start=1):
+    with maybeProgressBar(progress, nReads, "Reads    : ") as bar:
+        for readCount, read in enumerate(bam.fetch(contig=bamId), start=1):
             assert not read.is_unmapped
 
             addPairsInfo(
                 read.get_aligned_pairs(),
                 list(cigarTuplesToOperations(read.cigartuples)),
                 read.query_sequence,
-                ([1] * len(read.query_sequence) if ignoreQuality else
-                 read.query_qualities), referenceLength, includeSoftClipped,
-                correspondences, deletions, insertions)
+                (
+                    [1] * len(read.query_sequence)
+                    if ignoreQuality
+                    else read.query_qualities
+                ),
+                referenceLength,
+                includeSoftClipped,
+                correspondences,
+                deletions,
+                insertions,
+            )
 
             if DEBUG:
-                debug(f'read id     : {read.query_name}')
-                debug('query       :', read.query_sequence)
-                debug('query len   :', len(read.query_sequence))
-                debug(f'cigar       : {read.cigarstring}')
-                debug(f'match offset: {read.reference_start}')
-                debug(f'Pairs       : {read.get_aligned_pairs()}')
-                debug(f'Deletions   : {deletions}')
+                debug(f"read id     : {read.query_name}")
+                debug("query       :", read.query_sequence)
+                debug("query len   :", len(read.query_sequence))
+                debug(f"cigar       : {read.cigarstring}")
+                debug(f"match offset: {read.reference_start}")
+                debug(f"Pairs       : {read.get_aligned_pairs()}")
+                debug(f"Deletions   : {deletions}")
 
-                debug('correspondences:')
+                debug("correspondences:")
                 for offset, item in sorted(correspondences.items()):
-                    debug(f'  {offset}: {item}')
+                    debug(f"  {offset}: {item}")
 
-                debug('insertions:')
+                debug("insertions:")
                 for offset in sorted(insertions):
-                    debug(f'  {insertions[offset]}')
+                    debug(f"  {insertions[offset]}")
 
             bar.update(readCount)
 
     return correspondences, deletions, insertions
 
 
-def addPairsInfo(pairs, cigarOperations, query, qualities, referenceLength,
-                 includeSoftClipped, correspondences, deletions, insertions):
+def addPairsInfo(
+    pairs,
+    cigarOperations,
+    query,
+    qualities,
+    referenceLength,
+    includeSoftClipped,
+    correspondences,
+    deletions,
+    insertions,
+):
     """
     Add information about matched pairs of nucleotides.
 
@@ -434,13 +510,14 @@ def addPairsInfo(pairs, cigarOperations, query, qualities, referenceLength,
     # soft clip (not an insertion).
     if pairs[0][1] is None:
         assert cigarOperations[0] == CSOFT_CLIP, (
-            f'First CIGAR operation is {cigarOperations[0]}, '
-            f'not a soft clip')
+            f"First CIGAR operation is {cigarOperations[0]}, " f"not a soft clip"
+        )
 
     inInsertion = False
 
     for count, ((queryOffset, referenceOffset), cigarOperation) in enumerate(
-            zip(pairs, cigarOperations)):
+        zip(pairs, cigarOperations)
+    ):
 
         if queryOffset is None:
             # The query is missing something that is in the reference. So this
@@ -462,8 +539,7 @@ def addPairsInfo(pairs, cigarOperations, query, qualities, referenceLength,
                 # (soft-clipped) bases.
                 # assert lastReferenceOffset is not None
 
-                lookedBack, iOffset = insertionOffset(count, pairs,
-                                                      cigarOperations)
+                lookedBack, iOffset = insertionOffset(count, pairs, cigarOperations)
                 if not inInsertion:
                     inInsertion = True
                     if iOffset not in insertions:
@@ -487,10 +563,20 @@ def addPairsInfo(pairs, cigarOperations, query, qualities, referenceLength,
             correspondences[referenceOffset].append(base, quality)
 
 
-def fetchConsensus(bam, correspondences, deletions, insertions, reference,
-                   referenceLength, noCoverage, deletionThreshold,
-                   ignoreQuality, insertionCountThreshold, includeSoftClipped,
-                   progress):
+def fetchConsensus(
+    bam,
+    correspondences,
+    deletions,
+    insertions,
+    reference,
+    referenceLength,
+    noCoverage,
+    deletionThreshold,
+    ignoreQuality,
+    insertionCountThreshold,
+    includeSoftClipped,
+    progress,
+):
     """Compute a majority consensus using pysam's fetch function.
 
     @param bam: An open BAM file.
@@ -522,7 +608,7 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
     """
     # Do deletions.
     if DEBUG and deletions:
-        debug(f'There are {len(deletions)} deletions:')
+        debug(f"There are {len(deletions)} deletions:")
 
     actualDeletions = set()
     for offset, deletionCount in sorted(deletions.items()):
@@ -530,19 +616,21 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
         if count == 0 or deletionCount / count >= deletionThreshold:
             actualDeletions.add(offset)
             if DEBUG:
-                debug(f'  Offset {offset:5d}: deleted in {deletionCount:4d} '
-                      f'present in {count:4d}')
+                debug(
+                    f"  Offset {offset:5d}: deleted in {deletionCount:4d} "
+                    f"present in {count:4d}"
+                )
 
     if DEBUG:
-        debug(f'Actual deletions: {actualDeletions}')
-        debug('correspondences after deletions:')
+        debug(f"Actual deletions: {actualDeletions}")
+        debug("correspondences after deletions:")
         for offset, item in sorted(correspondences.items()):
-            debug(f'  {offset}: {item}')
+            debug(f"  {offset}: {item}")
 
     # Do insertions.
 
     if DEBUG:
-        debug(f'There are {len(insertions)} insertions.')
+        debug(f"There are {len(insertions)} insertions.")
 
     allOffsets = set(correspondences) | {0, referenceLength - 1}
     minOffset = min(allOffsets)
@@ -552,18 +640,16 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
     originalOffsets = {}
 
     if DEBUG:
-        debug(f'Offset limits: {minOffset} - {maxOffset}')
-        debug(f'Insertion count {len(insertions)}')
-        debug('final insertions:')
+        debug(f"Offset limits: {minOffset} - {maxOffset}")
+        debug(f"Insertion count {len(insertions)}")
+        debug("final insertions:")
         for offset in sorted(insertions):
             wanted = insertions[offset].readCount() >= insertionCountThreshold
             debug(f'  {"" if wanted else "un"}wanted {insertions[offset]}')
 
-    with maybeProgressBar(
-            progress, maxOffset - minOffset + 1, 'Collect  : ') as bar:
+    with maybeProgressBar(progress, maxOffset - minOffset + 1, "Collect  : ") as bar:
         insertCount = 0
-        for barCount, offset in enumerate(range(minOffset, maxOffset + 1),
-                                          start=1):
+        for barCount, offset in enumerate(range(minOffset, maxOffset + 1), start=1):
 
             if offset in insertions:
                 insertion = insertions[offset]
@@ -572,9 +658,9 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
                     insertionBases = insertion.resolve()
                     insertionLength = len(insertionBases)
                     if DEBUG:
-                        debug('INSERTION:', insertion)
-                        debug(f'  Resolved {insertionLength=}')
-                        debug(f'{insertionBases=}')
+                        debug("INSERTION:", insertion)
+                        debug(f"  Resolved {insertionLength=}")
+                        debug(f"{insertionBases=}")
 
                     for bases in insertionBases:
                         adjustedOffset = offset + insertCount
@@ -590,10 +676,12 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
 
             if offset in correspondences:
                 if DEBUG:
-                    debug(f'Offset {offset} Adding correspondences bases '
-                          f'{correspondences[offset]} to '
-                          f'{consensusBases[adjustedOffset]} at offset '
-                          f'{adjustedOffset}')
+                    debug(
+                        f"Offset {offset} Adding correspondences bases "
+                        f"{correspondences[offset]} to "
+                        f"{consensusBases[adjustedOffset]} at offset "
+                        f"{adjustedOffset}"
+                    )
                 consensusBases[adjustedOffset] += correspondences[offset]
 
             if adjustedOffset not in consensusBases:
@@ -605,16 +693,17 @@ def fetchConsensus(bam, correspondences, deletions, insertions, reference,
                         assert offset in actualDeletions
                 else:
                     otherBases[adjustedOffset] = (
-                        reference.sequence[offset] if noCoverage == 'reference'
-                        else noCoverage)
+                        reference.sequence[offset]
+                        if noCoverage == "reference"
+                        else noCoverage
+                    )
 
             bar.update(barCount)
 
     return correspondences, consensusBases, otherBases, originalOffsets
 
 
-def pileupCorrespondences(bam, bamId, referenceLength, includeSoftClipped,
-                          progress):
+def pileupCorrespondences(bam, bamId, referenceLength, includeSoftClipped, progress):
     """
     Get bases for offsets that correspond to the reference using pysam's
     pileup funciton.
@@ -631,17 +720,19 @@ def pileupCorrespondences(bam, bamId, referenceLength, includeSoftClipped,
     """
     correspondences = defaultdict(lambda: Bases())
 
-    with maybeProgressBar(progress, referenceLength, 'Pileup   : ') as bar:
+    with maybeProgressBar(progress, referenceLength, "Pileup   : ") as bar:
         for barCount, site in enumerate(bam.pileup(contig=bamId), start=1):
             referenceOffset = site.reference_pos
             for read in site.pileups:
                 if not includeSoftClipped:
-                    cigarOperations = list(cigarTuplesToOperations(
-                        read.alignment.cigartuples))
+                    cigarOperations = list(
+                        cigarTuplesToOperations(read.alignment.cigartuples)
+                    )
                 queryOffset = read.query_position
                 if queryOffset is None or (
-                        not includeSoftClipped and
-                        cigarOperations[queryOffset] == CSOFT_CLIP):
+                    not includeSoftClipped
+                    and cigarOperations[queryOffset] == CSOFT_CLIP
+                ):
                     continue
                     # Make sure an empty Bases instance is placed in our
                     # results so there's a sign that the reference offset
@@ -651,7 +742,8 @@ def pileupCorrespondences(bam, bamId, referenceLength, includeSoftClipped,
                     alignment = read.alignment
                     correspondences[referenceOffset].append(
                         alignment.query_sequence[queryOffset],
-                        alignment.query_qualities[queryOffset])
+                        alignment.query_qualities[queryOffset],
+                    )
 
             bar.update(barCount)
 
@@ -675,42 +767,55 @@ def compareCorrespondences(fp, fetch, pileup, threshold, minCoverage):
 
     unmatched = pileupOffsets - fetchOffsets
     if unmatched:
-        print(f'There are {len(unmatched)} sites obtained from pileup not '
-              f'present in fetch:', file=fp)
+        print(
+            f"There are {len(unmatched)} sites obtained from pileup not "
+            f"present in fetch:",
+            file=fp,
+        )
 
         for offset in sorted(unmatched):
-            print(f'  {offset + 1}: {pileup[offset]}', file=fp)
+            print(f"  {offset + 1}: {pileup[offset]}", file=fp)
 
     unmatched = fetchOffsets - pileupOffsets
     if unmatched:
-        print(f'There are {len(unmatched)} sites obtained from fetch not '
-              f'present in pileup:', file=fp)
+        print(
+            f"There are {len(unmatched)} sites obtained from fetch not "
+            f"present in pileup:",
+            file=fp,
+        )
 
         for offset in sorted(unmatched):
-            print(f'  {offset + 1}: {fetch[offset]}', file=fp)
+            print(f"  {offset + 1}: {fetch[offset]}", file=fp)
 
     common = fetchOffsets & pileupOffsets
     if common:
-        print(f'There are {len(common)} sites obtained from both fetch and '
-              f'pileup.', file=fp)
+        print(
+            f"There are {len(common)} sites obtained from both fetch and " f"pileup.",
+            file=fp,
+        )
         differenceCount = 0
         for offset in sorted(common):
             fetchBase = fetch[offset].consensus(
-                threshold, minCoverage, 'LOW-COVERAGE', 'NO-COVERAGE')
+                threshold, minCoverage, "LOW-COVERAGE", "NO-COVERAGE"
+            )
             pileupBase = pileup[offset].consensus(
-                threshold, minCoverage, 'LOW-COVERAGE', 'NO-COVERAGE')
+                threshold, minCoverage, "LOW-COVERAGE", "NO-COVERAGE"
+            )
             if fetchBase != pileupBase:
                 differenceCount += 1
-                print(f'  {offset + 1}: {fetchBase} != {pileupBase}', file=fp)
+                print(f"  {offset + 1}: {fetchBase} != {pileupBase}", file=fp)
                 if fetch[offset]:
-                    print(f'    Fetch : {fetch[offset]}', file=fp)
+                    print(f"    Fetch : {fetch[offset]}", file=fp)
                 if pileup[offset]:
-                    print(f'    Pileup: {pileup[offset]}', file=fp)
+                    print(f"    Pileup: {pileup[offset]}", file=fp)
 
         if differenceCount:
-            print(f'There were differences called at '
-                  f'{pct(differenceCount, len(common))} sites and '
-                  f'{pct(len(common) - differenceCount, len(common))} were '
-                  f'called identically.', file=fp)
+            print(
+                f"There were differences called at "
+                f"{pct(differenceCount, len(common))} sites and "
+                f"{pct(len(common) - differenceCount, len(common))} were "
+                f"called identically.",
+                file=fp,
+            )
         else:
-            print(f'All {len(common)} sites were called identically.', file=fp)
+            print(f"All {len(common)} sites were called identically.", file=fp)
