@@ -1,30 +1,48 @@
+import sys
 import six
+import numpy as np
 
+from json import dump, load
 from contextlib import contextmanager
 from collections import Counter, defaultdict
+from subprocess import CalledProcessError
 
 from pysam import (
     AlignmentFile, CMATCH, CINS, CDEL, CREF_SKIP, CSOFT_CLIP, CHARD_CLIP, CPAD,
     CEQUAL, CDIFF)
 
+from dark.process import Executor
+from dark.fasta import FastaReads
 from dark.reads import Read, DNARead
 
 
-class UnequalReferenceLengthError(Exception):
+class SamError(Exception):
+    "A SAM error."
+
+
+class UnequalReferenceLengthError(SamError):
     "The references of interest in a SAM/BAM file are not of the same length."
 
 
-class UnknownReference(Exception):
+class UnknownReference(SamError):
     "Reference sequence not found in SAM/BAM file."
 
 
-class InvalidSAM(Exception):
+class UnspecifiedReference(SamError):
+    "Reference sequence not specified."
+
+
+class ReferenceNameMismatchError(SamError):
+    "Reference name mismatch."
+
+
+class InvalidSAM(SamError):
     "SAM/BAM file has unexpected/invalid content."
 
 
 # From https://samtools.github.io/hts-specs/SAMv1.pdf
-_CONSUMES_QUERY = {CMATCH, CINS, CSOFT_CLIP, CEQUAL, CDIFF}
-_CONSUMES_REFERENCE = {CMATCH, CDEL, CREF_SKIP, CEQUAL, CDIFF}
+CONSUMES_QUERY = {CMATCH, CINS, CSOFT_CLIP, CEQUAL, CDIFF}
+CONSUMES_REFERENCE = {CMATCH, CDEL, CREF_SKIP, CEQUAL, CDIFF}
 
 
 @contextmanager
@@ -39,6 +57,20 @@ def samfile(filename):
     f.close()
 
 
+def samtoolsInstalled():
+    """
+    Test if samtools is installed.
+
+    @return: A C{bool}, which is C{True} if DIAMOND seems to be installed.
+    """
+    try:
+        Executor().execute('samtools help')
+    except CalledProcessError:
+        return False
+    else:
+        return True
+
+
 def samReferences(filenameOrSamfile):
     """
     List SAM/BAM file reference names.
@@ -105,7 +137,7 @@ def _hardClip(sequence, quality, cigartuples):
     hardClipCount = cigarLength = 0
     for (operation, length) in cigartuples:
         hardClipCount += operation == CHARD_CLIP
-        cigarLength += length if operation in _CONSUMES_QUERY else 0
+        cigarLength += length if operation in CONSUMES_QUERY else 0
 
     sequenceLength = len(sequence)
     if quality is not None:
@@ -214,16 +246,24 @@ class SAMFilter(object):
         self.filename = filename
         self.filterRead = filterRead
         self.referenceIds = referenceIds
+        self.storeQueryIds = storeQueryIds
         self.dropUnmapped = dropUnmapped
         self.dropSecondary = dropSecondary
         self.dropSupplementary = dropSupplementary
         self.dropDuplicates = dropDuplicates
         self.keepQCFailures = keepQCFailures
-        self.storeQueryIds = storeQueryIds
         self.minScore = minScore
         self.maxScore = maxScore
         self.scoreTag = scoreTag
 
+        # Detect when there are no filtering criteria, in which case
+        # self.filterAlignment can return immediately.
+        self.noFiltering = all((
+            filterRead is None, referenceIds is None,
+            not any((storeQueryIds, dropUnmapped, dropSecondary,
+                     dropSupplementary, dropDuplicates, keepQCFailures)),
+            minScore is None, maxScore is None))
+
     @staticmethod
     def addFilteringOptions(parser, samfileIsPositional=False,
                             samfileAction='store', samfileRequired=True,
@@ -354,6 +394,9 @@ class SAMFilter(object):
         @return: A C{bool}, C{True} if the alignment passes our filtering,
             C{False} if it should be discarded.
         """
+        if self.noFiltering:
+            return True
+
         if self.minScore is not None or self.maxScore is not None:
             try:
                 score = alignment.get_tag(self.scoreTag)
@@ -384,16 +427,16 @@ class SAMFilter(object):
         @return: A generator that yields pysam alignment instances that pass
             our filtering criteria.
         """
-        storeQueryIds = self.storeQueryIds
-
-        if storeQueryIds:
-            self.queryIds = queryIds = set()
+        if self.storeQueryIds:
+            queryIds = self.queryIds = set()
+        else:
+            queryIds = None
 
         lastAlignment = None
         count = 0
         with samfile(self.filename) as samAlignment:
             for count, alignment in enumerate(samAlignment.fetch(), start=1):
-                if storeQueryIds:
+                if queryIds is not None:
                     queryIds.add(alignment.query_name)
 
                 # Secondary and supplementary alignments may have a '*'
@@ -666,10 +709,10 @@ class PaddedSAM(object):
                 else:
                     raise ValueError('Unknown CIGAR operation:', operation)
 
-                if operation in _CONSUMES_QUERY:
+                if operation in CONSUMES_QUERY:
                     queryIndex += length
 
-                if operation in _CONSUMES_REFERENCE:
+                if operation in CONSUMES_REFERENCE:
                     referenceIndex += length
 
             if queryIndex != len(query):
@@ -702,3 +745,373 @@ class PaddedSAM(object):
                 read.alignment = alignment
 
             yield read
+
+
+class DistanceMatrix:
+    """
+    Maintain score (matching) information between reads and reference sequences
+    as read from a SAM file (or files) and provide methods for calculating
+    distance between references.
+    """
+    def __init__(self):
+        # self.scores is a similarity matrix between references and
+        # queries from a SAM file. The values are 1.0 or 0.0 when queries
+        # match / do not match references unless we are using alignment
+        # scores, as generated by tools like bowtie2 and bwa and stored in
+        # a SAM tag. In that case, the alignment score value is stored (see
+        # https://en.wikipedia.org/wiki/SAM_(file_format)#Optional_fields
+        # for SAM tag info).
+        #
+        # The dictionary is keyed by str reference ids and the values are
+        # dicts keyed by str query ids. The values of the sub-dictionaries
+        # are the float scores (similarities). E.g.
+        #
+        # {
+        #     'reference-1': {
+        #         'query-1': 77.5,
+        #         'query-2': 37.0,
+        #     },
+        #     'reference-2': {
+        #         'query-1': 78.0,
+        #     },
+        # }
+        #
+        # If a reference/query id pair is not present in self.scores, it
+        # means that query did not match that reference. The score method
+        # (below) will assign such a pair a similarity score of 0.0.
+        self.scores = {}
+
+    def addFile(self, filename, scoreTag=None):
+        """
+        Add information from a SAM file.
+
+        @param filename: A C{str} SAM file name to read.
+        @param scoreTag: A C{str} alignment score tag to use instead of binary
+            match / non-match values that are used if C{scoreTag} is C{None}.
+            The score tag must be present in the optional SAM fields.
+        """
+        if scoreTag:
+            def getScore(alignment, filename, count):
+                """
+                Get the alignment score from a SAM alignment.
+
+                @param alignment: A samtools alignment.
+                @param filename: The C{str} SAM file name being read.
+                @param count: The C{int} line number in the SAM file.
+                """
+                try:
+                    score = alignment.get_tag(scoreTag)
+                except KeyError:
+                    raise ValueError(
+                        f'Alignment {count} in {filename!r} has no '
+                        f'{scoreTag!r} score tag.')
+                else:
+                    if score < 0.0:
+                        raise ValueError(
+                            f'Alignment {count} in {filename!r} has tag '
+                            f'{scoreTag!r} with negative value ({score}).')
+                    return score
+        else:
+            def getScore(*args):
+                """
+                Return a binary score of 1.0 seeing as we know the query was
+                mapped and no score tag is in use.
+
+                @param args: ignored.
+                """
+                return 1.0
+
+        scores = self.scores
+
+        with samfile(filename) as samAlignment:
+            for count, alignment in enumerate(samAlignment.fetch(), start=1):
+                if alignment.is_unmapped:
+                    continue
+
+                queryId = alignment.query_name
+                referenceId = alignment.reference_name
+                score = getScore(alignment, filename, count)
+
+                try:
+                    preExisting = scores[referenceId][queryId]
+                except KeyError:
+                    if referenceId not in scores:
+                        scores[referenceId] = {}
+
+                    scores[referenceId][queryId] = score
+                else:
+                    if score > preExisting:
+                        scores[referenceId][queryId] = score
+
+    def score(self, referenceId, queryId):
+        """
+        Get the score for a reference and query.
+
+        Although this method name does not start with an underscore, it's not
+        likely to be used directly when this class is used to calculate
+        distances between references according to query matching. The scores
+        between references and queries (returned by this function) are just
+        a component of the overall distance.
+
+        @param referenceId: A C{str} reference id.
+        @param queryId: A C{str} query id.
+        @return: A C{float} score (zero if there was no match between the query
+            and reference) or if the reference id or query id have never been
+            seen. This could arguably cause a KeyError, but I decided against
+            that to keep the code simpler / faster. If you pass in unknown
+            query or reference ids, that's your problem (this should be very
+            unlikely because our caller is operating on a SAM file, so the
+            place they're most likely to be getting query and reference ids
+            from to pass us is from that same SAM file.
+        """
+        try:
+            return self.scores[referenceId][queryId]
+        except KeyError:
+            return 0.0
+
+    def jaccardDistance(self, referenceId1, referenceId2):
+        """
+        Get the Jaccard distance between two references.  See
+        https://en.wikipedia.org/wiki/Jaccard_index
+
+        @param referenceId1: A C{str} reference id.
+        @param referenceId2: A C{str} reference id.
+        @return: A C{float} distance.
+        """
+        queryIds1 = set(self.scores.get(referenceId1, []))
+        queryIds2 = set(self.scores.get(referenceId2, []))
+
+        denominator = len(queryIds1 | queryIds2)
+
+        if denominator:
+            numerator = len(queryIds1 & queryIds2)
+            similarity = numerator / denominator
+            distance = 1.0 - similarity
+            return distance
+        else:
+            # The references have no matching queries in common.
+            return 1.0
+
+    def soergelDistance(self, referenceId1, referenceId2):
+        """
+        Get the Soergel (i.e., weighted Jaccard) distance between two
+        references. See https://en.wikipedia.org/wiki/Jaccard_index
+
+        Note that this will be the same as the jaccardDistance unless a
+        scoreTag was used in reading the SAM file.
+
+        @param referenceId1: A C{str} reference id.
+        @param referenceId2: A C{str} reference id.
+        @return: A C{float} distance.
+        """
+        queryIds1 = set(self.scores.get(referenceId1, []))
+        queryIds2 = set(self.scores.get(referenceId2, []))
+
+        score = self.score
+        scores = [
+            (score(referenceId1, queryId), score(referenceId2, queryId))
+            for queryId in (queryIds1 | queryIds2)]
+
+        denominator = sum(max(a, b) for a, b in scores)
+
+        if denominator:
+            numerator = sum(min(a, b) for a, b in scores)
+            similarity = numerator / denominator
+            distance = 1.0 - similarity
+            return distance
+        else:
+            # Neither reference had a positive match against any query.
+            return 1.0
+
+    def matrix(self, referenceIds=None, metric='soergel', similarity=False,
+               returnDict=False):
+        """
+        Compute a distance matrix.
+
+        @param referenceIds: An iterable of C{str} reference ids. If C{None},
+            all known reference ids will be used.
+        @param metric: A C{str}, either 'soergel' or 'jaccard'.
+        @param similarity: If C{True}, return a similarity matrix.
+        @param returnDict: If C{True}, return a C{dict} (see @return, below).
+        @return: If C{returnDict} is C{False}, return a symmetric square
+            C{np.array} of C{float} inter-reference distances (or similarities
+            if C{similarity} is C{True}) in the range (0.0, 1.0). The order of
+            the entries in the rows and columns of the returned array matches
+            that of C{referenceIds} (if given) or the order in C{self.scores}
+            otherwise.  If C{returnDict} is C{True}, return a C{dict} of
+            C{dict}s, indexed by the two reference ids, with values as above.
+        """
+        assert metric in {'jaccard', 'soergel'}
+        referenceIds = tuple(referenceIds or self.scores)
+        nIds = len(referenceIds)
+        matrix = defaultdict(dict) if returnDict else np.empty((nIds, nIds))
+        identityValue = 1.0 if similarity else 0.0
+        func = (self.jaccardDistance if metric == 'jaccard' else
+                self.soergelDistance)
+
+        if similarity:
+            def metricFunc(ref1, ref2):
+                return 1.0 - func(ref1, ref2)
+        else:
+            def metricFunc(ref1, ref2):
+                return func(ref1, ref2)
+
+        for index1, ref1 in enumerate(referenceIds):
+            for index2, ref2 in enumerate(referenceIds):
+                i, j = (ref1, ref2) if returnDict else (index1, index2)
+                value = identityValue if i == j else metricFunc(ref1, ref2)
+                matrix[i][j] = matrix[j][i] = value
+
+        return matrix
+
+    def save(self, fp):
+        """
+        Save the similarity matrix as JSON.
+
+        @param fp: An open file pointer to write to.
+        """
+        dump(self.scores, fp, sort_keys=True, indent=4)
+
+    def load(self, fp):
+        """
+        Load a similarity matrix from a JSON file.
+
+        @param fp: An open file pointer to read from.
+        """
+        self.scores = load(fp)
+
+
+def getReferenceInfo(bam, bamFilename, bamId=None, referenceFasta=None,
+                     fastaId=None, quiet=False):
+    """
+    Get the id and length of a BAM file reference seqeunce.
+
+    @param bam: An open BAM file.
+    @param bamFilename: The C{str} file name of the BAM file.
+    @param bamId: A C{str} BAM file reference name indicating which aligned
+        reads to make a consensus from. If not given, will be inferred
+        from the BAM file header.
+    @param referenceFasta: A C{str} file name containing the sequence that was
+        aligned to in making the BAM file.
+    @param fastaId: A C{str} reference name indicating which sequence in
+        C{referenceFasta} to use as a reference. Only considered if
+        C{referenceFasta} is given. If not given and C{referenceFasta} is,
+        the reference id will be inferred from reference names in the BAM
+        header, or will be taken as the id of the first sequence in
+        C{referenceFasta}.
+    @param quiet: If C{True}, suppress diagnostic output.
+    @raise UnknownReference: For an unknown reference.
+    @raise UnspecifiedReference: If a reference is not given and cannot be
+        inferred.
+    @raise ReferenceNameMismatchError: If the names of the reference in the BAM
+        file and the FASTA reference file (if given) do not match (unless both
+        are explicitly given, in which case mismatching names are allowed as
+        long as the sequence lengths are the same).
+    @raise UnequalReferenceLengthError: If the lengths of the reference in the
+        BAM file and the FASTA reference file (if given) do not match
+    @return: A 2-tuple of C{str}, C{int} giving the refrence sequence id and
+        length.
+    """
+    bamReferences = set(samReferences(bam))
+    checkName = checkLength = True
+    inferredBamId = bamId is None
+    inferredFastaId = fastaId is None
+    referenceLength = None
+
+    if bamId is None:
+        inferredBamId = True
+    else:
+        if bamId not in bamReferences:
+            raise UnknownReference(
+                f'BAM file {str(bamFilename)!r} does not mention a reference '
+                f'with id {bamId!r}. Known references are: '
+                f'{", ".join(sorted(bamReferences))}.')
+
+        inferredBamId = False
+        tid = bam.get_tid(bamId)
+        referenceLength = bam.lengths[tid]
+
+        if fastaId is not None:
+            # Both ids have been given explicitly, so don't check that they
+            # are identical, assume the user knows what they are doing (we
+            # will just check the lengths, if necessary).
+            checkName = False
+
+    if referenceFasta is None:
+        reference = None
+    else:
+        if fastaId is None:
+            # We're given a reference FASTA file, but no id to use. Look at
+            # the sequences in the FASTA and take the first one that has a
+            # name and length matching a BAM reference (we could actually
+            # look to see if there are more than one and, if so, give an
+            # error if their sequences are not identical).
+            firstRead = None
+            for read in FastaReads(referenceFasta):
+                if firstRead is None:
+                    firstRead = read
+                if read.id in bamReferences:
+                    tid = bam.get_tid(read.id)
+                    if len(read) == bam.lengths[tid]:
+                        reference = read
+                        checkLength = checkName = False
+                        break
+            else:
+                # Try the first sequence in the FASTA file.
+                reference = firstRead
+
+            if firstRead is None:
+                raise UnknownReference(
+                    f'The FASTA reference file {str(referenceFasta)!r} '
+                    f'contained no sequences.')
+        else:
+            for read in FastaReads(referenceFasta):
+                if read.id == fastaId:
+                    reference = read
+                    break
+            else:
+                raise UnknownReference(f'No sequence with id {fastaId!r} '
+                                       f'found in {str(referenceFasta)!r}.')
+
+        # Set reference length if it has not already been set due to a
+        # given bamId.
+        if referenceLength is None:
+            referenceLength = len(reference)
+
+    if bamId is None:
+        if len(bamReferences) == 1:
+            # This is the only possibility.
+            bamId = tuple(bamReferences)[0]
+            tid = bam.get_tid(bamId)
+            referenceLength = bam.lengths[tid]
+        elif reference and reference.id in bamReferences:
+            tid = bam.get_tid(reference.id)
+            if len(reference) == bam.lengths[tid]:
+                bamId = reference.id
+                checkLength = checkName = False
+        else:
+            raise UnspecifiedReference(
+                f'Could not infer a BAM reference. Available references are: '
+                f'{", ".join(sorted(bamReferences))}.')
+
+    if inferredBamId and not quiet:
+        print(f'BAM reference id {bamId!r} inferred from context.',
+              file=sys.stderr)
+
+    if reference:
+        if inferredFastaId and not quiet:
+            print(f'FASTA reference id {reference.id!r} inferred from '
+                  f'context.', file=sys.stderr)
+
+        if checkName and reference.id != bamId:
+            raise ReferenceNameMismatchError(
+                f'Reference FASTA sequence name {reference.id!r} does '
+                f'not match the BAM id {bamId!r}.')
+
+        if checkLength and len(reference) != referenceLength:
+            raise UnequalReferenceLengthError(
+                f'Reference FASTA sequence {reference.id!r} has length '
+                f'{len(reference)}, but the BAM reference {bamId!r} has '
+                f'length {referenceLength}.')
+
+    return bamId, reference, referenceLength
