@@ -312,15 +312,17 @@ class TitlesAlignments(dict):
         else:
             self[title] = titleAlignments
 
-    def filter(self, minMatchingReads=None, minMedianScore=None,
-               withScoreBetterThan=None, minNewReads=None, minCoverage=None,
-               maxTitles=None, sortOn='maxScore', titleRegex=None,
-               negativeTitleRegex=None):
+    def filter(self, minMatchingReads=None, maxMatchingReads=None,
+               minMedianScore=None, withScoreBetterThan=None, minNewReads=None,
+               minCoverage=None, maxTitles=None, sortOn='maxScore',
+               titleRegex=None, negativeTitleRegex=None):
         """
         Filter the titles in self.
 
         @param minMatchingReads: titles that are matched by fewer reads
             are unacceptable.
+        @param maxMatchingReads: titles that are matched by more reads
+            are unacceptable.
         @param minMedianScore: sequences that are matched with a median
             bit score that is less are unacceptable.
         @param withScoreBetterThan: if the best score for a title is not
@@ -366,7 +368,7 @@ class TitlesAlignments(dict):
                 # than we should.
                 titles = self.sortTitles(sortOn)
         else:
-            titles = self.keys()
+            titles = list(self)
 
         if (titleRegex or negativeTitleRegex):
             titleFilter = TitleFilter(
@@ -391,6 +393,10 @@ class TitlesAlignments(dict):
                     titleAlignments.readCount() < minMatchingReads):
                 continue
 
+            if (maxMatchingReads is not None and
+                    titleAlignments.readCount() > maxMatchingReads):
+                continue
+
             # To compare the median score with another score, we must
             # convert both values to instances of the score class used in
             # this data set so they can be compared without us needing to
